@@ -123,6 +123,7 @@ struct nla_policy nat64_globals_policy[JNLAG_COUNT] = {
 	[JNLAG_JOOLD_FLUSH_DEADLINE] = { .type = NLA_U32 },
 	[JNLAG_JOOLD_CAPACITY] = { .type = NLA_U32 },
 	[JNLAG_JOOLD_MAX_PAYLOAD] = { .type = NLA_U32 },
+	[JNLAG_JOOLD_MAX_SESSIONS_PER_PACKET] = { .type = NLA_U32 },
 };
 
 int iname_validate(const char *iname, bool allow_null)
@@ -149,10 +150,10 @@ int xt_validate(xlator_type xt)
 
 int xf_validate(xlator_framework xf)
 {
-#ifdef XTABLES_DISABLED
-	return (xf == XF_NETFILTER) ? 0 : -EINVAL;
-#else
+#ifdef NETFILTER_XTABLES
 	return (xf == XF_NETFILTER || xf == XF_IPTABLES) ? 0 : -EINVAL;
+#else
+	return (xf == XF_NETFILTER) ? 0 : -EINVAL;
 #endif
 }
 
