@@ -5,7 +5,7 @@
 #include <linux/netfilter_ipv6.h>
 #include "common/config.h"
 
-#ifndef XTABLES_DISABLED
+#ifdef NETFILTER_XTABLES
 #include <linux/netfilter/x_tables.h>
 #endif
 
@@ -14,7 +14,7 @@ unsigned int hook_ipv6(void *priv, struct sk_buff *skb,
 unsigned int hook_ipv4(void *priv, struct sk_buff *skb,
 		const struct nf_hook_state *nhs);
 
-#ifndef XTABLES_DISABLED
+#ifdef NETFILTER_XTABLES
 
 int target_checkentry(const struct xt_tgchk_param *param);
 unsigned int target_ipv6(struct sk_buff *skb,
@@ -22,6 +22,6 @@ unsigned int target_ipv6(struct sk_buff *skb,
 unsigned int target_ipv4(struct sk_buff *skb,
 		const struct xt_action_param *param);
 
-#endif /* !XTABLES_DISABLED */
+#endif /* NETFILTER_XTABLES */
 
 #endif /* SRC_MOD_COMMON_KERNEL_HOOK_H_ */
