@@ -1,6 +1,7 @@
 #include "mod/common/rfc7915/core.h"
 
 #include "mod/common/log.h"
+#include "mod/common/skbuff.h"
 #include "mod/common/rfc7915/4to6.h"
 #include "mod/common/rfc7915/6to4.h"
 
@@ -18,6 +19,39 @@ static bool has_l4_hdr(struct xlation *state)
 	return false;
 }
 
+static bool has_null_page(struct sk_buff *skb)
+{
+	struct skb_shared_info *shinfo;
+	int i;
+
+	for (; skb; skb = skb->next) {
+		shinfo = skb_shinfo(skb);
+		for (i = 0; i < shinfo->nr_frags; i++)
+			if (skb_frag_page(&shinfo->frags[i]) == NULL)
+				return true;
+		if (shinfo->frag_list)
+			if (has_null_page(shinfo->frag_list))
+				return true;
+	}
+
+	return false;
+}
+
+static void __kfree_skb_list(struct xlation *state)
+{
+	struct sk_buff *out = state->out.skb;
+
+	if (has_null_page(out)) {
+		pr_info("Bug #352 found!\n");
+		skb_log(state->in.skb, "Incoming packet");
+		skb_log(out, "Outgoing packet");
+	} else {
+		kfree_skb_list(out);
+	}
+
+	state->out.skb = NULL;
+}
+
 verdict translating_the_packet(struct xlation *state)
 {
 	struct translation_steps const *steps;
@@ -61,6 +95,6 @@ verdict translating_the_packet(struct xlation *state)
 	return VERDICT_CONTINUE;
 
 revert:
-	kfree_skb_list(state->out.skb);
+	__kfree_skb_list(state);
 	return result;
 }
